#include <avr/io.h>
#include <avr/interrupt.h>  /* for sei() */
#include <util/delay.h>     /* for _delay_ms() */
#include <avr/pgmspace.h>   /* required by usbdrv.h */
#include "usbdrv.h"

#define RQ_SET_ROW 0
#define RQ_GET_COL 1


#define RQ_SET_COL 2
#define RQ_GET_ROW 3


/* ------------------------------------------------------------------------- */
/* ----------------------------- USB interface ----------------------------- */
/* ------------------------------------------------------------------------- */

usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
    usbRequest_t *rq = (void *)data;
    static uint8_t switch_state,light[2];  /* must stay valid when usbFunctionSetup returns */

    if (rq->bRequest == RQ_SET_ROW)
    {
        PORTB = rq->wValue.bytes[0];

        return 0;
    }
    else if (rq->bRequest == RQ_SET_COL)
    {
        PORTC = rq->wValue.bytes[0];

        return 0;
    }


    else if (rq->bRequest == RQ_GET_COL)
    {
        usbMsgPtr = (uchar*) &PINC;

        return sizeof(switch_state);
    }

    else if (rq->bRequest == RQ_GET_ROW)
    {
        usbMsgPtr = (uchar*) &PINB;

        return sizeof(switch_state);
    }
    else if (rq->bRequest == 4)
    {
        DDRC  = 0; 
        DDRB  = 127;
        PORTC = 127;
        PORTB = 127;
        return 0;
    }
    else if (rq->bRequest == 5)
    {
        DDRC  = 127; 
        DDRB  = 0;
        PORTC = 127;
        PORTB = 127;
        return 0;
    }

    return 0;   /* default for not implemented requests: return no data back to host */
}

/* ------------------------------------------------------------------------- */

int main(void)
{
    DDRC  = 0; 
    DDRB  = 127;

    
    PORTC = 127;                 // Enable pull-up at PC3
    PORTB = 127;

    usbInit();

    /* enforce re-enumeration, do this while interrupts are disabled! */
    usbDeviceDisconnect();
    _delay_ms(300);
    usbDeviceConnect();

    /* enable global interrupts */
    sei();

    /* main event loop */
    for(;;)
    {
        usbPoll();
    }

    return 0;
}

/* ------------------------------------------------------------------------- */
